type category = [ `base | `godi | `apps | `conf ]
type relop = [`lt | `gt | `le | `ge | `eq ]
type options = [ `configure | `bmake | `opt | `htdoc ]
type dep = (category * string * (relop * string) option)
(*          category , name   , (relop , version)  *)

val string_of_relop : relop -> string
val string_of_category : category -> string
val string_of_dep : dep -> string

type t =
    {
      package: string; (* without category- *)
      version: string;
      revision: int;
      category: category;
      depends: dep list;
      build_depends: dep list;
      sources_site: string;
      sources_basename: string;
      sources_extension: string;
      sources_unpacksto: string; (* this will usually be sources_basename *)
      homepage: string;
      maintainer: string;
      short_desc: string;
      long_desc: string;
      (* everything from  here down wants to be optional *)
      options: options list;
      docfiles: string list;
      all_target: string option; (* defaults to `all' *)
      opt_target: string option; (* defaults to `opt' *)
      install_target: string option; (* defaults to `install' *)
    }

val sample : t

(* the entire makefile for the given control information as a giant string *)
val makefile : t -> string

(* the contents of the DESCR file as a string *)
val descr : t -> string

(* writes out the generated package into a directory with the same name
   as its control.package. *)
val write_package : godi_localbase:string
                 -> control_file:string
                 -> control:t
                 -> ?filesdir:string
                 -> patches:string list
                 -> delete:bool
                 -> unit
                     -> unit
